@@ -375,7 +375,7 @@ class Javascript(ExpressionInner):
         parent.javascript = self.body
 
     def pretty_print(self, printer):
-        return ("js(body=%r)" % self.body, PRETTY_PRINT_EXPR_WRAPPED)
+        return ("js(%r)" % self.body, PRETTY_PRINT_EXPR_WRAPPED)
 
 class ToArray(ExpressionInner):
     def __init__(self, stream):
@@ -595,7 +595,7 @@ class ImplicitVar(ExpressionInner):
     def _write_ast(self, parent, opts):
         parent.type = p.Term.IMPLICIT_VAR
     def pretty_print(self, printer):
-        return ("r['@']", PRETTY_PRINT_EXPR_WRAPPED)
+        return ("r.row", PRETTY_PRINT_EXPR_WRAPPED)
 
 class ToStream(ExpressionInner):
     def __init__(self, array):
