@@ -79,39 +79,11 @@ import query_language_pb2 as p
 import net
 import types
 
-class RDBShortcut(object):
-    """Get the value of a variable or attribute.
-
-    Filter and map bind the current element to the implicit variable.
-    To access the implicit variable (i.e. 'current' row), use the
-    following:
-
-    >>> r['@']
-
-
-    To access an attribute of the implicit variable, pass the attribute name.
-
-    >>> r['name']
-    >>> r['@']['name']
-
-
-    See information on scoping rules for more details.
-
-    >>> table('users').filter(r['age'] == 30) # access attribute age from the implicit row variable
-    >>> table('users').filter(r['address']['city') == 'Mountain View') # access subattribute city
-                                                                       # of attribute address from
-                                                                       # the implicit row variable
-    >>> table('users').filter(lambda row: row['age') == 30)) # access attribute age from the
-                                                             # variable 'row'
+def r(exr):
+    """Wrap a python object with a RQL expression
+       This is a shortcut for `expr`.
     """
-    def __getitem__(self, key):
-        if key == "@":
-            expr = JSONExpression(internal.ImplicitVar())
-        else:
-            expr = JSONExpression(internal.ImplicitAttr(key))
-        return expr
-
-r = RDBShortcut()
+    return expr(exr)
 
 class BaseQuery(object):
     """A base class for all ReQL queries. Queries can be run by calling the
@@ -423,22 +395,27 @@ class JSONExpression(ReadQuery):
         """
         return JSONExpression(internal.Not(self))
 
-    def contains(self, name):
-        """Determines whether an object has a key called `name`.
-        Evaluates to `true` if the key is present, or `false` if not.
+    def contains(self, *attrs):
+        """Determines whether an object has all of the given keys.
+        Evaluates to `true` if all keys are present, or `false` if not.
 
         If `self` is not an object, fails when the query is run.
 
-        :param name: The key to check for
-        :type name: string
+        :param *attrs: The keys to check for
+        :type *attrs: string
         :returns: :class:`JSONExpression` evaluating to a boolean
 
         >>> expr({}).contains("foo").run()
         False
         >>> expr({"a": 1}).contains("a").run()
         True
+        >>> expr({"a": 1}).contains("a", "b").run()
+        False
         """
-        return JSONExpression(internal.Has(self, name))
+        query = JSONExpression(internal.Has(self, attrs[0]))
+        for attr in attrs[1:]:
+            query = query & JSONExpression(internal.Has(self, attr))
+        return query
 
     def merge(self, other):
         """Combines two objects by taking all the key-value pairs from both. If
@@ -481,7 +458,7 @@ class JSONExpression(ReadQuery):
         [3, 4, 5]
         """
         if isinstance(predicate, dict):
-            predicate = JSONExpression(internal.All(*[r[k] == v for k, v in predicate.iteritems()]))
+            predicate = JSONExpression(internal.All(*[row[k] == v for k, v in predicate.iteritems()]))
         if not isinstance(predicate, FunctionExpr):
             predicate = FunctionExpr(predicate)
 
@@ -886,7 +863,7 @@ class StreamExpression(ReadQuery):
         :returns: :class:`StreamExpression` or :class:`MultiRowSelection` (same as input)
         """
         if isinstance(predicate, dict):
-            predicate = JSONExpression(internal.All(*[r[k] == v for k, v in predicate.iteritems()]))
+            predicate = JSONExpression(internal.All(*[row[k] == v for k, v in predicate.iteritems()]))
         if not isinstance(predicate, FunctionExpr):
             predicate = FunctionExpr(predicate)
 
@@ -1216,7 +1193,7 @@ def expr(val):
         return JSONExpression(internal.LiteralNull())
     elif isinstance(val, bool):
         return JSONExpression(internal.LiteralBool(val))
-    elif isinstance(val, (int, float)):
+    elif isinstance(val, (int, float, long)):
         return JSONExpression(internal.LiteralNumber(val))
     elif isinstance(val, types.StringTypes):
         return JSONExpression(internal.LiteralString(val))
@@ -1263,13 +1240,8 @@ def letvar(name):
     "Evaluates a variable in the context of let"
     return JSONExpression(internal.Var(name))
 
-def js(expr=None, body=None):
-    if (expr is not None) + (body is not None) != 1:
-        raise ValueError('exactly one of expr or body must be passed')
-    if body is not None:
-        return JSONExpression(internal.Javascript(body))
-    else:
-        return JSONExpression(internal.Javascript(u'return (%s);' % expr))
+def js(body):
+    return JSONExpression(internal.Javascript(body))
 
 def let(bindings, body):
     if len(bindings) == 0:
@@ -1714,3 +1686,7 @@ def error(msg=''):
 # this happens at the end since it's a circular import
 import internal
 
+"""Access the currently bound row in any method that takes a lambda such as
+   `map` and `filter`.
+"""
+row = JSONExpression(internal.ImplicitVar())
